#
# spec file for package plasma5-pk-updates
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plasma5-pk-updates
Version:        0.3.2+git70
Release:        2.10
Summary:        Software Update Manager for Plasma
License:        GPL-3.0-or-later
Group:          System/Packages
URL:            https://www.kde.org/
Source:         plasma-pk-updates-%{version}.tar.xz
# Updated translations
Source1:        plasma5-pk-updates-lang.tar.xz
# PATCH-FIX-UPSTREAM
Patch1:         0001-Set-and-use-implicitHeight-instead-of-height.patch
BuildRequires:  PackageKit-Qt5-devel
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= 1.3.0
BuildRequires:  kcoreaddons-devel >= 5.25.0
BuildRequires:  ki18n-devel >= 5.25.0
BuildRequires:  knotifications-devel >= 5.25.0
BuildRequires:  plasma-framework-devel >= 5.25.0
BuildRequires:  solid-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       PackageKit
Recommends:     %{name}-lang = %{version}
# Use a fake version number higher than the last provided apper version (0.9.2)
Provides:       apper = 1.0
Obsoletes:      apper < 1.0
Obsoletes:      apper-lang < 1.0

%description
Plasma applet for software updates using PackageKit.

%lang_package

%prep
%autosetup -p1 -n plasma-pk-updates-%{version} -a 1
echo -e 'find_package(KF5I18n CONFIG REQUIRED)\nki18n_install(po)' >> CMakeLists.txt

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %find_lang pkupdates plasma-pk-updates.lang
  %find_lang plasma_applet_org.kde.plasma.pkupdates plasma-pk-updates.lang

%files lang -f plasma-pk-updates.lang

%files
%license LICENSE
%{_kf5_qmldir}/
%{_kf5_plasmadir}/
%{_kf5_appstreamdir}/
%{_kf5_notifydir}/
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.pkupdates.desktop

%changelog
* Thu Apr 14 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix package list with newer Plasma/Frameworks
  (a version update might be lacking some translations for string
  changes):
  * 0001-Set-and-use-implicitHeight-instead-of-height.patch
* Fri Mar  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 0.3.2+git70:
  * Improve EULA dialog layout after QQC2 regressions
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Use git master directly
- Use a complete plasma5-pk-updates-lang.tar.xz
- Update to version 0.3.2+git67:
  * Port config dialog to QtQuick Controls 2
  * Lower required QtQuick.Layouts version to 1.12
  * Fix expansion handling of PackageDelegate items
  * Consistent spacing in PackageDelegate
  * Port completely to PC3 by using PlasmaExtras.ListItem
  * Don't show "no updates" message when checking failed
  * Refactor tracking of overall package selection state
  * Fix state of "Select all packages" checkbox
  * Port to Layouts and PlaceholderMessage as well to fix layout issues
  * [applet] Port mostly to PlasmaComponents3
  * Also treat ErrorNotAuthorized as temporary
  * Limit to one automatic check each 10 minutes
  * Don't refresh the cache forcibly
  * Accumulate restart requests to show the notification at transaction end
    (boo#1103679, boo#1174239)
  * Don't default to showing that the check for updates failed
  * Don't show an error for a failed automatic refresh
  * Make action buttons translatable
  * Add support for license prompts
  * Port away from KDELibs4Support, use Solid::Power interface
  * Remove explicit initialization of default constructed members
  * Fix warning, remove unsigned int < 0 check
  * Fix minor typos
  * Make the notifications less obtrusive
  * Use own eventIds and ComponentName instead of generic plasma workspace ones
  * Fix usage of 0 for null pointer constants
  * Replace KIconLoader + pixmaps with standard icon names
  * Don't force a check for updates when the applet runs
  * Several fixes related to the network state and applet messages/notifications.
- Drop all patches, now upstream:
  * desktop.patch
  * 0001-Hide-updates-and-checkbox-when-system-is-offline.patch
  * 0002-Add-its-own-messageChanged-NOTIFY-signal-to-message.patch
  * 0003-Delay-PkUpdates-checkUpdates-calls-if-the-network-is-offline.patch
  * 0001-Replace-KIconLoader-pixmaps-with-standard-icon-names.patch
  * 0002-Fix-usage-of-0-for-null-pointer-constants.patch
  * 0003-Use-own-eventIds-and-ComponentName-instead-of-generi.patch
  * 0004-Make-the-notifications-less-obtrusive.patch
  * 0006-Remove-explicit-initialization-of-default-constructe.patch
  * 0007-Port-away-from-KDELibs4Support-use-Solid-Power-inter.patch
  * 0001-Add-support-for-license-prompts.patch
  * 0001-Don-t-show-an-error-for-a-failed-automatic-refresh.patch
  * 0001-Limit-to-one-automatic-check-each-10-minutes.patch
  * 0001-Also-treat-ErrorNotAuthorized-as-temporary.patch
* Fri Dec 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix package build with plasma-framework 5.89.0.
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Fri Jun 11 2021 Christophe Giboudeaux <christophe@krop.fr>
- Use %%cmake_build instead of %%make_jobs.
* Thu Apr 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Fix 0001-Limit-to-one-automatic-check-each-10-minutes.patch
  to handle msecs properly
* Fri Apr 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to make avoiding error messages more effective (boo#1156387):
  * 0001-Limit-to-one-automatic-check-each-10-minutes.patch
  * 0001-Also-treat-ErrorNotAuthorized-as-temporary.patch
* Mon Feb 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to avoid error messages for a locked db (boo#1161501):
  * 0001-Don-t-show-an-error-for-a-failed-automatic-refresh.patch
* Tue Jan 28 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update german translations to remove a superfluous fullstop
  (kde#386751)
* Mon Aug 26 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Implement EULA handling (boo#1148168):
  * 0001-Add-support-for-license-prompts.patch
- Enable install updates functionality on Tumbleweed again (boo#1030829):
  * Drop 0001-Hide-option-to-install-updates-on-Tumbleweed.patch
* Mon Jun 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- More spec file cleanup
* Sun Jun 23 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add some upstream patches to make the notifications less obtrusive
  + 0001-Replace-KIconLoader-pixmaps-with-standard-icon-names.patch
  + 0002-Fix-usage-of-0-for-null-pointer-constants.patch
  + 0003-Use-own-eventIds-and-ComponentName-instead-of-generi.patch
  + 0004-Make-the-notifications-less-obtrusive.patch
- Rebase 0001-Hide-option-to-install-updates-on-Tumbleweed.patch
- Remove kdelibs4-support dependency
  + 0006-Remove-explicit-initialization-of-default-constructe.patch
  + 0007-Port-away-from-KDELibs4Support-use-Solid-Power-inter.patch
- spec file cleanup
  + remove defattr
  + remove some conditional code for 13.2
* Mon Apr 29 2019 Markus S <kamikazow@opensuse.org>
- Dependency on PackageKit
- Fix summary
- https URL
* Thu Mar 21 2019 alarrosa@suse.com
- Add patches already approved by upstream to delay any check for updates
  until the network is online if the network is offline . The patches
  also fix some visibility issues of widgets that don't make sense if
  the network is offline. This is part of the fix for boo#1103678.
  * 0001-Hide-updates-and-checkbox-when-system-is-offline.patch
  * 0002-Add-its-own-messageChanged-NOTIFY-signal-to-message.patch
  * 0003-Delay-PkUpdates-checkUpdates-calls-if-the-network-is-offline.patch
- Rebase patch:
  * 0001-Hide-option-to-install-updates-on-Tumbleweed.patch
* Wed Dec 19 2018 wbauer@tmo.at
- Add desktop.patch to also translate the plasmoid name to French
  (boo#1086068)
* Wed Dec 19 2018 wbauer@tmo.at
- Add plasma5-pk-updates-lang.tar.xz with updated French
  translations, the included ones are rather incomplete
  (boo#1086068)
* Tue Jun 12 2018 fabian@ritter-vogt.de
- Add patch to hide the "Install updates" button on Tumbleweed as
  the zypp PK backend can't handle it correctly:
  * 0001-Hide-option-to-install-updates-on-Tumbleweed.patch
* Fri May 25 2018 wbauer@tmo.at
- Update to 0.3.2. Changes:
  * Use \n instead of <br> for the extra part of the summary
  * Close the plasmoid after updates got installed
  * Fix build with PackageKit-Qt 1.0.x
  * List known updates on startup
  * Show that the last check failed if no updates available
  * Only save the last update timestep on success
  * Add DefaultEvent flag to fix notification for relogin/restart
  * concat the string
- Change Source URL to download.kde.org
- Drop plasma-pk-updates-lang.tar.xz, the translations are
  included in the released source tarball now
- Drop patches merged upstream:
  * 0001-concat-the-string.patch
  * 0001-Add-DefaultEvent-flag-to-fix-notification-for-relogi.patch
  * 0001-Only-save-the-last-update-timestep-on-success.patch
  * 0002-Show-that-the-last-check-failed-if-no-updates-availa.patch
  * 0003-List-known-updates-on-startup.patch
  * 0001-Close-the-plasmoid-after-updates-got-installed.patch
  * 0001-Use-n-instead-of-br-for-the-extra-part-of-the-summar.patch
- Mark LICENSE file with %%license instead of %%doc
* Thu May 17 2018 christophe@krop.fr
- Update translations (boo#1093743)
* Wed May  9 2018 fabian@ritter-vogt.de
- Add patch to fix tooltip text with security or important updates (boo#1090375):
  * 0001-Use-n-instead-of-br-for-the-extra-part-of-the-summar.patch
* Fri Feb  9 2018 fabian@ritter-vogt.de
- Add patch to close the plasmoid after update installation (boo#1077633):
  * 0001-Close-the-plasmoid-after-updates-got-installed.patch
* Sat Jan 27 2018 wbauer@tmo.at
- Update translations (boo#1077851)
* Thu Jan  4 2018 fabian@ritter-vogt.de
- Fix refresh logic on startup:
  * 0001-Only-save-the-last-update-timestep-on-success.patch
  * 0002-Show-that-the-last-check-failed-if-no-updates-availa.patch
  * 0003-List-known-updates-on-startup.patch
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 0.3.1. Changes:
  * concat the string
  * reload the cache when the updates had been installed meanwhile manually
  * Re-check selected packages once any is selected/deselected
  * Remove Plasma/PopupApplet from desktop file
  * Add notification about required restart/logout
  * Fix typo in icon name
  * Use new breeze icons
  * Make it compile with GCC < 5
  * Simplify the logic a bit
  * Change the refresh logic and avoid unnecessary calls to the Packagekit Daemon
  * Add a checkbox to select/deselect all packages
  * Use native plasma components
- Remove patches, now upstream:
  * 0001-Add-notification-about-required-restart-logout.patch
  * 0002-Remove-Plasma-PopupApplet-from-desktop-file.patch
  * fix-typo-in-icon-name.patch
  * use-new-breeze-icons.patch
  * use-native-plasma-components.patch
  * change-refresh-logic.patch
  * gcc48.diff
  * add-desktopfile-translations.patch
- Add patch to fix relogin/restart notification (boo#951580)
  * 0001-Add-DefaultEvent-flag-to-fix-notification-for-relogi.patch
- Add patch to fix translation of status string:
  * 0001-concat-the-string.patch
- Generate an updated plasma-pk-updates-lang.tar.xz
* Thu Jan 19 2017 fabian@ritter-vogt.de
- Add upstream commits:
  * 0001-Add-notification-about-required-restart-logout.patch
  * 0002-Remove-Plasma-PopupApplet-from-desktop-file.patch
* Sat Sep 24 2016 wbauer@tmo.at
- Add add-desktopfile-translations.patch to translate the name and
  description of the plasmoid
- Update translations to the latest versions from SVN (boo#990362)
* Mon Aug 15 2016 fabian@ritter-vogt.de
- Add upstream commits fix-typo-in-icon-name.patch and
  use-new-breeze-icons.patch
* Fri Aug 12 2016 hrvoje.senjan@gmail.com
- Adjust filelist for the plasmoid appdata, installed with KF > 5.25.0
* Mon Feb 15 2016 wbauer@tmo.at
- Add use-native-plasma-components.patch: fixes problems with dark
  Plasma themes (boo#953669, kde#359308)
* Fri Feb 12 2016 tittiatcoke@gmail.com
- Add translations  (plasma-pk-updates-lang.tar.xz)
* Thu Feb 11 2016 tittiatcoke@gmail.com
- Add patch change-refresh-logic.patch. This prevents the plasmoid
  from starting the PackageKit Daemon on a hourly basis. This also
  prevents unnecessary notifications.
  (boo#955352)
* Fri Feb  5 2016 tittiatcoke@gmail.com
- Change the obsoletes for apper to a higher version number to
  make sure that it gets removed. Current apper version is 0.9.2 and
  therefore higher than the version of plasma5-pk-updates
* Wed Oct 21 2015 hrvoje.senjan@gmail.com
- Obsolete apper
